(function UMDBundle(context, umdDefs) {
  for (let [name, dependencies, definition] of umdDefs) {
    if (typeof define === "function" && define.amd) {
      dependencies = Object.keys(dependencies).map(p => p.replace(/^\.\//, ""));
      define(name, dependencies, definition);
    } else if (typeof module !== "undefined" && module.exports) {
      dependencies = Object.keys(dependencies).map(p => require(p));
      module.exports[name] = definition(...dependencies);
    } else {
      dependencies = Object.values(dependencies).map(n => context[n]);
      context[name] = definition(...dependencies);
    }
  }
})(typeof globalThis != "undefined" ? globalThis : typeof global != "undefined" ? global : typeof window != "undefined" ? window : typeof self != "undefined" ? self : new Function("return this")(), [["Helpers", {
  "path": "Mz_570462467",
  "fs": "Mz_495308967",
  "os": "Mz_433970632",
  "@babel/types": "Mz_643814648"
}, function DEF(Mz_570462467, Mz_495308967, Mz_433970632, Mz_643814648) {
  "use strict";

  var path = Mz_570462467;
  var fs = Mz_495308967;
  var os = Mz_433970632;
  var T = Mz_643814648;
  let _exp = {};
  _exp.findParentStatement = findParentStatement;
  _exp.isFunction = isFunction;
  _exp.isAssignmentTarget = isAssignmentTarget;
  _exp.expandHomeDir = expandHomeDir;
  _exp.addRelativeCurrentDir = addRelativeCurrentDir;
  _exp.splitPath = splitPath;
  _exp.isDirectory = isDirectory;
  _exp.checkPath = checkPath;
  _exp.generateName = generateName; // ******************************

  var HOMEPATH = os.homedir();
  var generatedNames = {};

  function findParentStatement(path) {
    if (T.isProgram(path.node)) {
      return null;
    } else if (T.isStatement(path.node)) {
      return path;
    } else {
      return findParentStatement(path.parentPath);
    }
  }

  function isFunction(path) {
    return T.isFunctionDeclaration(path.node) || T.isFunctionExpression(path.node);
  }

  function isAssignmentTarget(path) {
    if (T.isProgram(path.node) || T.isStatement(path.node) || isFunction(path) || T.isAssignmentPattern(path.node)) {
      return false;
    } else if (T.isAssignmentExpression(path.parent)) {
      return path.parent.left == path.node;
    } else {
      return isAssignmentTarget(path.parentPath);
    }
  }

  function expandHomeDir(pathStr) {
    if (pathStr[0] == "~" && (pathStr.length == 1 || pathStr[1] == "/")) {
      pathStr = pathStr.replace(/^~/, HOMEPATH);
    }

    return pathStr;
  }

  function addRelativeCurrentDir(pathStr) {
    return !path.isAbsolute(pathStr) && !/^(?:(?:\.+[/\\]+)|(?:~(?:[/\\].*)$))/.test(pathStr) ? `./${pathStr}` : pathStr;
  }

  function splitPath(fromPathStr, pathStr) {
    var fromDir = path.resolve(fromPathStr);

    if (!isDirectory(fromDir)) {
      fromDir = path.dirname(fromDir);
    }

    var fullPathStr = path.resolve(fromDir, pathStr);
    var basePath = fullPathStr.substr(0, fromDir.length);
    var relativePath = fullPathStr.substr(fromDir.length + 1);
    return [basePath, relativePath];
  }

  function isDirectory(pathStr) {
    return checkPath(pathStr) && fs.lstatSync(pathStr).isDirectory();
  }

  function checkPath(pathStr) {
    return fs.existsSync(pathStr);
  }

  function generateName() {
    do {
      var name = `Mz_${Math.round(Math.random() * 1E9)}`;
    } while (name in generatedNames);

    generatedNames[name] = true;
    return name;
  }

  return _exp;
}], ["Analysis", {
  "@babel/traverse": "Mz_583114175",
  "@babel/types": "Mz_577193569",
  "@babel/generator": "Mz_348778173",
  "@babel/parser": "Mz_259689872",
  "./helpers.js": "Helpers"
}, function DEF(Mz_583114175, Mz_577193569, Mz_348778173, Mz_259689872, Helpers) {
  "use strict";

  var {
    default: traverse
  } = Mz_583114175;
  var T = Mz_577193569;
  var {
    default: generate
  } = Mz_348778173;
  var {
    parse
  } = Mz_259689872;
  var {
    findParentStatement,
    isFunction,
    isAssignmentTarget
  } = Helpers;
  let _exp = {};
  _exp.identifyRequiresAndExports = identifyRequiresAndExports;
  _exp.analyzeRequires = analyzeRequires;
  _exp.analyzeExports = analyzeExports; // ******************************

  function identifyRequiresAndExports(codePath, code) {
    var programPath;
    var requireStatements = new Set();
    var exportStatements = new Set();
    var requireCalls = new WeakMap();
    var exportReferences = new WeakMap();
    var visitors = {
      Program: {
        exit(path) {
          programPath = path;
        }

      },
      CallExpression: {
        exit(path) {
          // require(..) call?
          if (T.isIdentifier(path.node.callee, {
            name: "require"
          })) {
            // require(" some string literal ") ?
            if (path.node.arguments.length == 1 && T.isStringLiteral(path.node.arguments[0])) {
              let parentStatementPath = findParentStatement(path.parentPath);

              if (parentStatementPath) {
                requireStatements.add(parentStatementPath);

                if (!requireCalls.has(parentStatementPath)) {
                  requireCalls.set(parentStatementPath, []);
                }

                requireCalls.get(parentStatementPath).push(path);
              }
            } // non-string literals not supported
            else {
                throw new Error("Unsupported: require(..) statement without a single string-literal argument");
              }
          }
        }

      },
      MemberExpression: {
        exit(path) {
          // module.exports?
          if (isModuleExports(path.node)) {
            let parentStatementPath = findParentStatement(path.parentPath);

            if (parentStatementPath) {
              exportStatements.add(parentStatementPath);

              if (!exportReferences.has(parentStatementPath)) {
                exportReferences.set(parentStatementPath, {
                  type: isAssignmentTarget(path) ? "assignment" : "expression",
                  refs: []
                });
              }

              exportReferences.get(parentStatementPath).refs.push(path);
            }
          }
        }

      },
      Identifier: {
        exit(path) {
          // exports?
          if (path.node.name == "exports" && // not part of a member expression? (intentionally excludes module.exports)
          !T.isMemberExpression(path.parent, {
            property: path.node
          }) && ( // in a left-hand assignment target postion?
          isAssignmentTarget(path) || // not a function parameter
          !isFunction(path.parentPath) && // not a property in an object literal
          !T.isObjectProperty(path.parent, {
            key: path.node
          }))) {
            let parentStatementPath = findParentStatement(path.parentPath);

            if (parentStatementPath) {
              exportStatements.add(parentStatementPath);

              if (!exportReferences.has(parentStatementPath)) {
                exportReferences.set(parentStatementPath, {
                  type: isAssignmentTarget(path) ? "assignment" : "expression",
                  refs: []
                });
              }

              exportReferences.get(parentStatementPath).refs.push(path);
            }
          }
        }

      }
    };
    var programAST = parse(code, {
      sourceFilename: codePath
    });
    traverse(programAST, visitors);
    var convertRequires = analyzeRequires(requireStatements, requireCalls);
    var convertExports = analyzeExports(exportStatements, exportReferences);
    return {
      programAST,
      programPath,
      convertRequires,
      convertExports
    };
  }

  function analyzeRequires(requireStatements, requireCalls) {
    var convertRequires = [];

    for (let stmtPath of requireStatements) {
      if (!T.isProgram(stmtPath.parent)) {
        throw new Error("Require statements must be at the top-level of the program");
      }

      let stmtReqCalls = [...requireCalls.get(stmtPath)]; // standalone require(".."")?

      if (T.isExpressionStatement(stmtPath.node) && T.isCallExpression(stmtPath.node.expression) && stmtReqCalls.length == 1 && stmtReqCalls[0].node == stmtPath.node.expression) {
        // unset entry to mark this require(..) expression as handled
        stmtReqCalls[0] = false;
        let call = stmtPath.node.expression;
        let specifier = call.arguments[0].extra.rawValue; // console.log(`import ${ specifier };`);

        convertRequires.push({
          esmType: "bare-import",
          umdType: "remove-require-unique",
          specifier,
          context: {
            statement: stmtPath
          }
        });
      } // var/let/const declaration statement?
      else if (T.isVariableDeclaration(stmtPath.node)) {
          for (let [declIdx, declNode] of stmtPath.node.declarations.entries()) {
            // no require(..) in this declaration, so skip?
            if (!hasRequireCalls(stmtPath, declNode.init, stmtReqCalls)) {
              continue;
            }

            let decl = stmtPath.get(`declarations.${declIdx}`); // normal identifier declaration? var x = ..

            if (T.isIdentifier(declNode.id)) {
              // call as initialization assignment? var x = require(..)
              if (T.isCallExpression(declNode.init) && stmtReqCalls.find(p => p.node == declNode.init)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == declNode.init)] = false;
                let callPath = decl.get("init");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue; // console.log(`import * as ${ declNode.id.name } from ${ specifier };`);
                // console.log(`import ${ declNode.id.name } from ${ specifier };`);

                convertRequires.push({
                  esmType: "default-import",
                  umdType: "default-require",
                  binding: {
                    target: declNode.id.name
                  },
                  specifier,
                  context: {
                    statement: stmtPath,
                    declarator: decl,
                    declarationIdx: declIdx,
                    requireCall: callPath
                  }
                });
              } else if ( // require(..) is part of a simple member expression?
              isSimpleMemberExpression(declNode.init, declNode) && stmtReqCalls.find(p => p.node == declNode.init.object)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == declNode.init.object)] = false;
                let callPath = decl.get("init.object");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue;
                let target = declNode.id.name;
                let source = T.isIdentifier(declNode.init.property) ? declNode.init.property.name : T.isStringLiteral(declNode.init.property) ? declNode.init.property.value : undefined; // console.log(`import { ${ binding } } from ${ specifier };`);

                convertRequires.push({
                  esmType: "named-import",
                  umdType: "named-dependency",
                  binding: {
                    source,
                    target
                  },
                  specifier,
                  context: {
                    statement: stmtPath,
                    declarator: decl,
                    declarationIdx: declIdx,
                    requireCall: callPath
                  }
                });
              }
            } // destructuring assignment? var { x } = require(..)
            else if (T.isObjectPattern(declNode.id) && T.isCallExpression(declNode.init) && stmtReqCalls.find(p => p.node == declNode.init)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == declNode.init)] = false;
                let callPath = decl.get("init");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue;
                let pattern = declNode.id;
                let bindings = [];

                for (let targetProp of pattern.properties) {
                  // simple destructuring target?
                  if (!targetProp.computed && T.isIdentifier(targetProp.value)) {
                    let source = T.isIdentifier(targetProp.key) ? targetProp.key.name : T.isStringLiteral(targetProp.key) ? targetProp.key.value : undefined;
                    bindings.push({
                      source,
                      target: targetProp.value.name
                    });
                    continue;
                  } // if we get here, the destructuring wasn't of a supported ESM import form


                  throw new Error("Unsupported: destructuring pattern not ESM import-compatible");
                } // console.log(`import { ${ binding } } from ${ specifier };`);


                convertRequires.push({
                  esmType: "named-import",
                  umdType: "destructured-dependency",
                  binding: bindings,
                  specifier,
                  context: {
                    statement: stmtPath,
                    declarator: decl,
                    declarationIdx: declIdx,
                    requireCall: callPath
                  }
                });
              }
          }
        } // non-declaration assignment statement?
        else if (T.isExpressionStatement(stmtPath.node) && T.isAssignmentExpression(stmtPath.node.expression)) {
            let assignment = stmtPath.node.expression; // regular identifier assignment? x = ..

            if (T.isIdentifier(assignment.left)) {
              // simple call assignment? x = require(..)
              if (stmtReqCalls.find(p => p.node == assignment.right)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == assignment.right)] = false;
                let callPath = stmtPath.get("expression.right");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue;
                let target = assignment.left.name; // console.log(`import * as ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);
                // console.log(`import ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);

                convertRequires.push({
                  esmType: "default-import-indirect",
                  umdType: "indirect-target",
                  binding: {
                    source: "default",
                    target,
                    uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
                  },
                  specifier,
                  context: {
                    statement: stmtPath,
                    requireCall: callPath
                  }
                });
              } else if ( // require(..) part of a simple member expression?
              isSimpleMemberExpression(assignment.right, assignment) && stmtReqCalls.find(p => p.node == assignment.right.object)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == assignment.right.object)] = false;
                let callPath = stmtPath.get("expression.right.object");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue;
                let target = assignment.left.name;
                let source = T.isIdentifier(assignment.right.property) ? assignment.right.property.name : T.isStringLiteral(assignment.right.property) ? assignment.right.property.value : undefined; // console.log(`import { ${ binding } } from ${ specifier }; ${ target } = ${ target$1 };`);

                convertRequires.push({
                  esmType: "named-import-indirect",
                  umdType: "indirect-source-target",
                  binding: {
                    source,
                    target,
                    uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
                  },
                  specifier,
                  context: {
                    statement: stmtPath,
                    requireCall: callPath
                  }
                });
              }
            } // destructuring assignment? { x } = require(..)
            else if (T.isObjectPattern(assignment.left) && stmtReqCalls.find(p => p.node == assignment.right)) {
                // unset entry to mark this require(..) expression as handled
                stmtReqCalls[stmtReqCalls.findIndex(p => p.node == assignment.right)] = false;
                let callPath = stmtPath.get("expression.right");
                let call = callPath.node;
                let specifier = call.arguments[0].extra.rawValue;
                let pattern = assignment.left;
                let bindings = [];

                for (let targetProp of pattern.properties) {
                  // simple destructuring target?
                  if (!targetProp.computed && T.isIdentifier(targetProp.value)) {
                    let source = T.isIdentifier(targetProp.key) ? targetProp.key.name : T.isStringLiteral(targetProp.key) ? targetProp.key.value : undefined;
                    bindings.push({
                      source,
                      target: targetProp.value.name,
                      uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
                    });
                    continue;
                  } // if we get here, the `require(..)` wasn't of a supported form


                  throw new Error("Unsupported: destructuring pattern not ESM import-compatible");
                }

                if (bindings.length > 0) {
                  // console.log(`import { ${ binding } } from ${ specifier }; ${ target } = ${ target$1 };`);
                  convertRequires.push({
                    esmType: "named-import-indirect",
                    umdType: "indirect-source-target",
                    binding: bindings,
                    specifier,
                    context: {
                      statement: stmtPath,
                      requireCall: callPath
                    }
                  });
                }
              } // default or named re-export? (aka, "combo")
              // ie, module.exports = require(..).. OR module.exports.x = require(..)..
              else if (isModuleExports(assignment.left) || isSimpleMemberExpression(assignment.left, assignment) && isModuleExports(assignment.left.object)) {
                  let target = assignment.left; // require(..) by itself?

                  if (stmtReqCalls.find(p => p.node == assignment.right)) {
                    // unset entry to mark this require(..) expression as handled
                    stmtReqCalls[stmtReqCalls.findIndex(p => p.node == assignment.right)] = false;
                    let callPath = stmtPath.get("expression.right");
                    let call = callPath.node;
                    let specifier = call.arguments[0].extra.rawValue; // console.log(`import * as ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);
                    // console.log(`import ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);

                    convertRequires.push({
                      esmType: "default-import-indirect",
                      umdType: "indirect-target",
                      binding: {
                        source: "default",
                        target,
                        uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
                      },
                      specifier,
                      context: {
                        statement: stmtPath,
                        requireCall: callPath
                      }
                    });
                  } // require(..).x form?
                  else if (isSimpleMemberExpression(assignment.right, assignment) && stmtReqCalls.find(p => p.node == assignment.right.object)) {
                      // unset entry to mark this require(..) expression as handled
                      stmtReqCalls[stmtReqCalls.findIndex(p => p.node == assignment.right.object)] = false;
                      let callPath = stmtPath.get("expression.right.object");
                      let call = callPath.node;
                      let specifier = call.arguments[0].extra.rawValue;
                      let source = T.isIdentifier(assignment.right.property) ? assignment.right.property.name : T.isStringLiteral(assignment.right.property) ? assignment.right.property.value : undefined; // console.log(`import { ${ binding } } from ${ specifier }; ${ target } = ${ target$1 };`);

                      convertRequires.push({
                        esmType: "named-import-indirect",
                        umdType: "indirect-source-target",
                        binding: {
                          source,
                          target,
                          uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
                        },
                        specifier,
                        context: {
                          statement: stmtPath,
                          requireCall: callPath
                        }
                      });
                    }
                }
          } // remove entries marked as handled


      stmtReqCalls = stmtReqCalls.filter(Boolean); // any unhandled require(..) occurences in this statement?
      // handle them as simple expression substitutions

      if (stmtReqCalls.length > 0) {
        convertRequires = [...convertRequires, ...stmtReqCalls.map(function handleReqCall(reqCallPath) {
          return analyzeRequireSubstitutions(stmtPath, reqCallPath);
        })];
      }
    }

    return convertRequires;
  }

  function analyzeRequireSubstitutions(stmtPath, callPath) {
    var specifier = callPath.node.arguments[0].extra.rawValue; // require(..).x form?

    if (isSimpleMemberExpression(callPath.parent, callPath.parentPath.parent)) {
      let source = T.isIdentifier(callPath.parent.property) ? callPath.parent.property.name : T.isStringLiteral(callPath.parent.property) ? callPath.parent.property.value : undefined; // console.log(`import { ${ binding } } from ${ specifier }; ${ target } = ${ target$1 };`);

      return {
        esmType: "substitute-named-import-indirect",
        umdType: "substitute-indirect-source-target",
        binding: {
          source,
          uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
        },
        specifier,
        context: {
          statement: stmtPath,
          requireCall: callPath,
          expression: callPath.parentPath
        }
      };
    } // assume just simple require(..) form
    else {
        // console.log(`import * as ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);
        // console.log(`import ${ target$1 } from ${ specifier }; ${ target } = ${ target$1 };`);
        return {
          esmType: "substitute-default-import-indirect",
          umdType: "substitute-indirect-target",
          binding: {
            source: "default",
            uniqueTarget: stmtPath.scope.generateUidIdentifier("imp").name
          },
          specifier,
          context: {
            statement: stmtPath,
            requireCall: callPath
          }
        };
      }
  }

  function analyzeExports(exportStatements, exportReferences) {
    var convertExports = [];

    for (let stmtPath of exportStatements) {
      if (!T.isProgram(stmtPath.parent)) {
        throw new Error("Exports expressions must be at the top-level of the program");
      }

      let stmtExportExpressions = exportReferences.get(stmtPath);
      let exprRefs = stmtExportExpressions.refs;

      if (stmtExportExpressions.type == "assignment") {
        // single export assignment?
        if (T.isExpressionStatement(stmtPath.node) && T.isAssignmentExpression(stmtPath.node.expression) && exprRefs.length == 1) {
          let assignment = stmtPath.node.expression;
          let target = assignment.left;
          let source = assignment.right; // assigning to `exports` or `module.exports`?

          if (target == exprRefs[0].node) {
            // exporting an identifier?
            if (T.isIdentifier(source) && source.name != "undefined") {
              // console.log(`export default ${ source.name };`);
              convertExports.push({
                esmType: "default-export",
                umdType: "default-assignment",
                binding: {
                  source
                },
                context: {
                  statement: stmtPath,
                  exportsExpression: stmtPath.get("expression.left")
                }
              });
              continue;
            } // exporting any other value/expression
            else {
                // console.log("export default ..;");
                convertExports.push({
                  esmType: "default-export",
                  umdType: "default-assignment",
                  binding: {
                    source
                  },
                  context: {
                    statement: stmtPath,
                    exportsExpression: stmtPath.get("expression.left")
                  }
                });
                continue;
              }
          } // assigning to property on module.exports? module.exports.x = ..
          else if (T.isMemberExpression(target, {
              object: exprRefs[0].node
            }) && isSimpleMemberExpression(target, assignment)) {
              let exportName = T.isIdentifier(target.property) ? target.property.name : T.isStringLiteral(target.property) ? target.property.value : undefined; // exporting an identifier?

              if (T.isIdentifier(source) && source.name != "undefined") {
                // console.log(`export { ${ source.name } as ${ exportName } };`);
                convertExports.push({
                  esmType: "named-export",
                  umdType: "named-export",
                  binding: {
                    source: source.name,
                    target: exportName
                  },
                  context: {
                    statement: stmtPath,
                    exportsExpression: stmtPath.get("expression.left.object")
                  }
                });
                continue;
              } // exporting member-expression that can be destructured?
              else if (isSimpleMemberExpression(source, assignment)) {
                  let sourceName = T.isIdentifier(source.property) ? source.property.name : T.isStringLiteral(source.property) ? source.property.value : undefined; // console.log(`export var { ${ sourceName }: ${ exportName } } = ${ source.object }`);

                  convertExports.push({
                    esmType: "destructured-declaration-export",
                    umdType: "named-export",
                    binding: {
                      sourceName,
                      source: source.object,
                      target: exportName
                    },
                    context: {
                      statement: stmtPath,
                      exportsExpression: stmtPath.get("expression.left.object")
                    }
                  });
                  continue;
                } // exporting any other value/expression
                else {
                    // console.log(`var ${ exportName }$1 = ..; export { ${exportName}$1 as ${ exportName } };`);
                    convertExports.push({
                      esmType: "named-declaration-export",
                      umdType: "named-export",
                      binding: {
                        source,
                        target: exportName,
                        uniqueTarget: stmtPath.scope.generateUidIdentifier("exp").name
                      },
                      context: {
                        statement: stmtPath,
                        exportsExpression: stmtPath.get("expression.left.object")
                      }
                    });
                    continue;
                  }
            }
        }
      } else if (stmtExportExpressions.type == "expression") {
        for (let ref of exprRefs) {
          convertExports.push({
            esmType: "substitute-module-exports-reference",
            umdType: "substitute-module-exports-reference",
            context: {
              statement: stmtPath,
              exportsExpression: ref
            }
          });
        }

        continue;
      } // if we get here, the module.exports expression wasn't of a supported form


      throw new Error("Unsupported: exports expression not ESM export-compatible");
    }

    return convertExports;
  }

  function hasRequireCalls(stmtPath, node, stmtReqCalls) {
    for (let reqCall of stmtReqCalls) {
      let curPath = reqCall;

      while (curPath && curPath != stmtPath) {
        if (curPath.node == node) return true;
        curPath = curPath.parentPath;
      }
    }

    return false;
  }

  function isModuleExports(node) {
    return T.isIdentifier(node, {
      name: "exports"
    }) || T.isMemberExpression(node) && T.isIdentifier(node.object, {
      name: "module"
    }) && ( // single property expression via . operator? module.exports
    !node.computed && T.isIdentifier(node.property, {
      name: "exports"
    }) || // single property expression via [".."] operator? x["y"]
    node.computed && T.isStringLiteral(node.property, {
      value: "exports"
    }));
  }

  function isSimpleMemberExpression(node, parentNode) {
    return T.isMemberExpression(node) && ( // single property expression via . operator? x.y
    !node.computed && T.isIdentifier(node.property) || // single property expression via [".."] operator? x["y"]
    node.computed && T.isStringLiteral(node.property)) && !T.isCallExpression(parentNode);
  }

  return _exp;
}], ["UMD", {
  "fs": "Mz_466090529",
  "path": "Mz_322419703",
  "@babel/traverse": "Mz_707553573",
  "@babel/types": "Mz_373888578",
  "@babel/generator": "Mz_926276926",
  "@babel/parser": "Mz_321653590",
  "toposort": "Mz_900719684",
  "./helpers.js": "Helpers",
  "./analysis.js": "Analysis"
}, function DEF(Mz_466090529, Mz_322419703, Mz_707553573, Mz_373888578, Mz_926276926, Mz_321653590, Mz_900719684, Helpers, Analysis) {
  "use strict";

  var fs = Mz_466090529;
  var path = Mz_322419703;
  var {
    default: traverse
  } = Mz_707553573;
  var T = Mz_373888578;
  var {
    default: generate
  } = Mz_926276926;
  var {
    parse
  } = Mz_321653590;
  var toposort = Mz_900719684;
  var {
    expandHomeDir,
    addRelativeCurrentDir,
    splitPath,
    generateName
  } = Helpers;
  var {
    identifyRequiresAndExports,
    analyzeRequires,
    analyzeExports
  } = Analysis;
  let _exp = {};
  _exp = build;
  _exp.build = build;
  _exp.bundle = bundle;
  _exp.index = index;
  _exp.sortDependencies = sortDependencies; // ******************************

  var UMDTemplate = fs.readFileSync(path.join(__dirname, "umd-template.js"), "utf-8");
  var UMDBundleTemplate = fs.readFileSync(path.join(__dirname, "umd-bundle-template.js"), "utf-8");

  function build(config, pathStr, code, depMap) {
    var {
      programAST,
      programPath,
      convertRequires,
      convertExports
    } = identifyRequiresAndExports(pathStr, code);
    var [, origModulePathStr] = splitPath(config.from, pathStr);
    var modulePathStr = addRelativeCurrentDir(origModulePathStr);
    var moduleName = depMap[modulePathStr]; // rename source file .cjs extension (per config)

    modulePathStr = renameCJS(config, modulePathStr); // unknown module?

    if (!moduleName) {
      modulePathStr = origModulePathStr;

      if (config.ignoreUnknownDependency) {
        moduleName = generateName();
        depMap[modulePathStr] = moduleName;
      } else {
        throw new Error(`Unknown module: ${modulePathStr}`);
      }
    }

    var refDeps = {};
    var defaultExportSet = false;

    for (let req of convertRequires) {
      // normalize dependency path
      let [, origSpecifierPath] = splitPath(config.from, expandHomeDir(req.specifier));
      let specifierPath = addRelativeCurrentDir(origSpecifierPath);
      let depName = depMap[specifierPath]; // rename source file .cjs extension (per config)

      specifierPath = renameCJS(config, specifierPath); // unknown/unnamed dependency?

      if (!depName) {
        specifierPath = req.specifier;

        if (req.umdType == "remove-require-unique" || config.ignoreUnknownDependency) {
          depName = generateName();
          depMap[specifierPath] = depName;
        } else {
          throw new Error(`Unknown dependency: ${req.specifier}`);
        }
      } // track which dependencies from the map we've actually referenced


      refDeps[specifierPath] = depName; // process require() statements/expressions

      if (req.umdType == "remove-require-unique") {
        req.context.statement.remove();
      } else if (req.umdType == "default-require") {
        // variable declaration different name than registered dependency-name?
        if (depName != req.binding.target) {
          // replace require(..) call with registered dependency-name
          req.context.requireCall.replaceWith(T.Identifier(depName));
        } else {
          // remove whole declarator/statement
          req.context.declarator.remove();
        }
      } else {
        // replace require(..) call with registered dependency-name
        req.context.requireCall.replaceWith(T.Identifier(depName));
      }
    }

    if (convertExports.length > 0) {
      // setup substitute module-exports target
      let $module$exports = T.Identifier(programPath.scope.generateUidIdentifier("exp").name);
      convertExports[0].context.statement.insertBefore(T.VariableDeclaration("let", [T.VariableDeclarator($module$exports, T.ObjectExpression([]))])); // note: appending to end of body so that we don't `return` too early

      programPath.pushContainer("body", T.ReturnStatement($module$exports)); // convert all exports

      for (let expt of convertExports) {
        // default export?
        if (expt.umdType == "default-assignment") {
          // only one module.exports assignment allowed per module
          registerDefaultExport(expt.context.exportsExpression);
        }

        expt.context.exportsExpression.replaceWith($module$exports);
      }
    } // construct UMD from template


    var umdAST = parse(UMDTemplate);
    traverse(umdAST, {
      Program: {
        exit(path) {
          var callExprPath = path.get("body.0.expression"); // set module-name

          callExprPath.get("arguments.0").replaceWith(T.StringLiteral(moduleName)); // set dependencies and named parameters

          var dependencies = Object.entries(refDeps);
          var defFuncPath = callExprPath.get("arguments.3");

          if (dependencies.length > 0) {
            let dependenciesPath = callExprPath.get("arguments.2");

            for (let [depPath, depName] of dependencies) {
              // add dependency entry
              dependenciesPath.node.properties.push(T.ObjectProperty(T.StringLiteral(depPath), T.StringLiteral(depName))); // add named parameter

              defFuncPath.node.params.push(T.Identifier(depName));
            }
          }
        }

      }
    }); // add UMD wrapper to program

    var umdWrapper = T.clone(umdAST.program.body[0],
    /*deep=*/
    true,
    /*withoutLoc=*/
    true);
    programPath.unshiftContainer("body", umdWrapper); // get reference to UMD definition function

    var defFuncBodyPath = programPath.get("body.0.expression.arguments.3.body"); // add strict-mode directive to UMD definition function?

    if (programAST.program.directives.length > 0 && programAST.program.directives[0].value.value == "use strict") {
      defFuncBodyPath.node.directives.push(T.Directive(T.DirectiveLiteral("use strict")));
      programAST.program.directives.shift();
    } // move all the program's top-level statements into the UMD definition function


    while (programAST.program.body.length > 1) {
      let stmt = programPath.get(`body.1`);
      let newStmt = T.cloneDeep(stmt.node);
      defFuncBodyPath.pushContainer("body", newStmt);
      stmt.remove();
    }

    return { ...generate(programAST),
      ast: programAST,
      refDeps,
      pathStr: modulePathStr,
      name: moduleName
    };

    function registerDefaultExport(context) {
      // TODO: include `context` in error reporting
      // already assigned to module-exports? only one assignment allowed per module
      if (defaultExportSet) {
        throw new Error("Multiple replacements of exports not allowed in the same module");
      }

      defaultExportSet = true;
    }
  }

  function bundle(config, umdBuilds) {
    try {
      // make sure dependencies are ordered correctly
      umdBuilds = sortDependencies(umdBuilds);
    } catch (err) {
      if (!config.ignoreCircularDependency) {
        throw new Error("Circular dependency not supported in UMD builds/bundles");
      }
    } // construct UMD bundle from template


    var programPath;
    var umdBundleAST = parse(UMDBundleTemplate);
    traverse(umdBundleAST, {
      Program: {
        exit(path) {
          programPath = path;
        }

      }
    }); // get reference to UMD definition function

    var defListPath = programPath.get("body.0.expression.arguments.1"); // insert all UMDs

    for (let umd of umdBuilds) {
      // append UMD to program body
      programPath.pushContainer("body", T.clone(umd.ast.program.body[0],
      /*deep=*/
      true,
      /*withoutLoc=*/
      true)); // reference inserted UMD's call expression

      let callExprPath = programPath.get("body.1.expression"); // move UMD definition parts into bundle wrapper array

      let name = T.clone(callExprPath.get("arguments.0").node,
      /*deep=*/
      true,
      /*withoutLoc=*/
      true);
      let deps = T.clone(callExprPath.get("arguments.2").node,
      /*deep=*/
      true,
      /*withoutLoc=*/
      true);
      let def = T.clone(callExprPath.get("arguments.3").node,
      /*deep=*/
      true,
      /*withoutLoc=*/
      true);
      defListPath.pushContainer("elements", T.ArrayExpression([name, deps, def])); // remove inserted UMD

      programPath.get("body.1").remove();
    }

    return generate(umdBundleAST);
  }

  function index(config, umdBuilds, depMap) {
    try {
      // make sure dependencies are ordered correctly
      umdBuilds = sortDependencies(umdBuilds);
    } catch (err) {
      if (!config.ignoreCircularDependency) {
        throw new Error("Circular dependency not supported in UMD builds/bundles");
      }
    }

    var modulePathStr = "./index.js";
    var altModulePathStr = modulePathStr.replace(/\.js$/, ".cjs");
    var moduleName = depMap[modulePathStr || altModulePathStr] || "Index"; // remove a dependency self-reference (if any)

    depMap = Object.fromEntries(Object.entries(depMap).filter(([dPath, dName]) => dPath != modulePathStr && dPath != altModulePathStr)); // handle any file extension renaming, per config

    modulePathStr = renameCJS(config, modulePathStr); // construct UMD from template

    var umdAST = parse(UMDTemplate);
    traverse(umdAST, {
      Program: {
        exit(path) {
          var callExprPath = path.get("body.0.expression"); // set module-name

          callExprPath.get("arguments.0").replaceWith(T.StringLiteral(moduleName)); // set dependencies and named parameters

          var dependencies = Object.entries(depMap);
          var defFuncPath = callExprPath.get("arguments.3");
          var defFuncBodyPath = defFuncPath.get("body");
          var returnObjectContents = [];

          if (dependencies.length > 0) {
            let dependenciesPath = callExprPath.get("arguments.2");

            for (let [depPath, depName] of dependencies) {
              // rename source file .cjs extension (per config)
              depPath = renameCJS(config, depPath); // add dependency entry

              dependenciesPath.node.properties.push(T.ObjectProperty(T.StringLiteral(depPath), T.StringLiteral(depName))); // add named parameter

              defFuncPath.node.params.push(T.Identifier(depName)); // add re-export assignment statement to function body

              returnObjectContents.push(T.ObjectProperty(T.Identifier(depName), T.Identifier(depName),
              /*computed=*/
              false,
              /*shorthand=*/
              true));
            }
          } // return substitute module-exports target


          defFuncBodyPath.pushContainer("body", T.ReturnStatement(T.ObjectExpression(returnObjectContents))); // add strict mode directive

          defFuncBodyPath.node.directives.push(T.Directive(T.DirectiveLiteral("use strict")));
        }

      }
    });
    return { ...generate(umdAST),
      ast: umdAST,
      refDeps: depMap,
      pathStr: modulePathStr,
      name: moduleName
    };
  }

  function sortDependencies(umdBuilds) {
    // map of module paths to the builds
    var depMap = {};

    for (let umd of umdBuilds) {
      depMap[umd.pathStr] = umd;
    } // construct graph edges (dependency relationships)


    var depsGraph = [];

    for (let umd of umdBuilds) {
      for (let refDepPath of Object.keys(umd.refDeps)) {
        if (refDepPath in depMap) {
          depsGraph.push([umd, depMap[refDepPath]]);
        }
      }
    } // perform topological sort


    return toposort.array(umdBuilds, depsGraph).reverse();
  }

  function renameCJS(config, pathStr) {
    if (config[".cjs"]) {
      return pathStr.replace(/\.cjs$/, ".js");
    }

    return pathStr;
  }

  return _exp;
}], ["ESM", {
  "@babel/types": "Mz_978610155",
  "@babel/template": "Mz_723246233",
  "@babel/generator": "Mz_183623484",
  "./helpers.js": "Helpers",
  "./analysis.js": "Analysis"
}, function DEF(Mz_978610155, Mz_723246233, Mz_183623484, Helpers, Analysis) {
  "use strict";

  var T = Mz_978610155;
  var {
    default: template
  } = Mz_723246233;
  var {
    default: generate
  } = Mz_183623484;
  var {
    expandHomeDir,
    addRelativeCurrentDir,
    splitPath,
    generateName
  } = Helpers;
  var {
    identifyRequiresAndExports,
    analyzeRequires,
    analyzeExports
  } = Analysis;
  let _exp = {};
  _exp = build;
  _exp.build = build;
  _exp.index = index; // ******************************

  function build(config, pathStr, code, depMap) {
    var {
      programAST,
      programPath,
      convertRequires,
      convertExports
    } = identifyRequiresAndExports(pathStr, code);
    var [, origModulePathStr] = splitPath(config.from, pathStr);
    var modulePathStr = addRelativeCurrentDir(origModulePathStr);
    var moduleName = depMap[modulePathStr]; // handle any file extension renaming, per config

    modulePathStr = renameFileExtension(config, modulePathStr);

    if (!moduleName) {
      modulePathStr = origModulePathStr;
      moduleName = generateName();
      depMap[modulePathStr] = moduleName;
    }

    var refDeps = {};
    var $module$exports;
    var defaultExportSet = false; // find any combo statements that have both a require and an export in it

    var reqStmts = new Map();
    var convertCombos = new Map();

    for (let [idx, req] of convertRequires.entries()) {
      // substitution requires? can't be part of a combo statement
      if (req.esmType == "substitute-named-import-indirect" || req.esmType == "substitute-default-import-indirect") {
        continue;
      }

      if (!reqStmts.has(req.context.statement)) {
        reqStmts.set(req.context.statement, {
          reqIdxs: [],
          reqs: []
        });
      }

      let entry = reqStmts.get(req.context.statement);
      entry.reqIdxs.push(idx);
      entry.reqs.push(req);
    }

    for (let [idx, expt] of convertExports.entries()) {
      // found a combo statement?
      if (reqStmts.has(expt.context.statement)) {
        let {
          reqIdxs,
          reqs
        } = reqStmts.get(expt.context.statement); // unsert original require entries

        for (let reqIdx of reqIdxs) {
          convertRequires[reqIdx] = false;
        } // unset original export entry


        convertExports[idx] = false;

        if (!convertCombos.has(expt.context.statement)) {
          convertCombos.set(expt.context.statement, {
            requires: [...reqs],
            exports: []
          });
        }

        convertCombos.get(expt.context.statement).exports.push(expt);
      }
    } // remove unset require/export entries (from combos)


    convertRequires = convertRequires.filter(Boolean);
    convertExports = convertExports.filter(Boolean); // convert all combo require/export statements

    for (let [stmt, combo] of convertCombos.entries()) {
      let req = combo.requires[0]; // normalize dependency path

      let [, origSpecifierPath] = splitPath(config.from, expandHomeDir(req.specifier));
      let specifierPath = addRelativeCurrentDir(origSpecifierPath);

      if (!(specifierPath in depMap)) {
        specifierPath = origSpecifierPath;
      }

      let depName = depMap[specifierPath]; // handle any file extension renaming, per config

      specifierPath = renameFileExtension(config, specifierPath); // unknown/unnamed dependency?

      if (!depName) {
        specifierPath = req.specifier;
        depName = generateName();
        depMap[specifierPath] = depName;
      } // track which dependencies from the map we've actually referenced


      refDeps[specifierPath] = depName;
      let expt = combo.exports[0]; // combined form? export { x [as y] } from ".."

      if ((req.esmType == "default-import-indirect" || req.esmType == "named-import-indirect") && (expt.esmType == "named-declaration-export" || expt.esmType == "destructured-declaration-export")) {
        // default export?
        if (expt.binding.target == "default") {
          // only one default export allowed per module
          registerDefaultExport(expt.context.exportsExpression);
        }

        stmt.replaceWith(T.ExportNamedDeclaration(null, [T.ExportSpecifier(T.Identifier(req.binding.source), T.Identifier(expt.binding.target))], T.StringLiteral(specifierPath)));
      } // default indirect? import * as x + export default x
      else if (req.esmType == "default-import-indirect" && expt.esmType == "default-export") {
          // only one default export allowed per module
          registerDefaultExport(expt.context.exportsExpression);
          let uniqTarget = T.Identifier(req.binding.uniqueTarget);
          stmt.replaceWithMultiple([T.ImportDeclaration([// import * as x from .. ?
          config.namespaceImport ? T.ImportNamespaceSpecifier(uniqTarget) : // otherwise, import x from ..
          T.ImportDefaultSpecifier(uniqTarget)], T.StringLiteral(specifierPath)), T.ExportDefaultDeclaration(uniqTarget)]);
        } // indirect with module-exports replacement? import .. + $module$exports
        else if (expt.esmType == "substitute-module-exports-reference") {
            // only one default export allowed per module
            registerDefaultExport(expt.context.exportsExpression); // handle require(..) call replacement first

            if (req.esmType == "substitute-default-import-indirect") {
              let uniqTarget = T.Identifier(req.binding.uniqueTarget); // insert default-import statement

              req.context.statement.insertBefore(T.ImportDeclaration([config.namespaceImport ? T.ImportNamespaceSpecifier(uniqTarget) : T.ImportDefaultSpecifier(uniqTarget)], T.StringLiteral(specifierPath))); // replace require(..) call

              req.context.requireCall.replaceWith(uniqTarget);
            } else if (req.esmType == "substitute-named-import-indirect") {
              let uniqTarget = T.Identifier(req.binding.uniqueTarget); // insert named-import statement

              req.context.statement.insertBefore(T.ImportDeclaration([req.binding.source == "default" ? T.ImportDefaultSpecifier(uniqTarget) : T.ImportSpecifier(uniqTarget, T.Identifier(req.binding.source))], T.StringLiteral(specifierPath))); // replace require(..).x call

              req.context.expression.replaceWith(uniqTarget);
            } // now handle module.exports replacement


            if (!$module$exports) {
              $module$exports = createModuleExports(programPath, stmt, convertExports[convertExports.length - 1].context.statement);
            }

            expt.context.exportsExpression.replaceWith($module$exports);
          } // should not get here
          else {
              throw new Error("Unsupported: combined import/export form not ESM compatible");
            }
    } // convert all requires to ESM imports


    for (let req of convertRequires) {
      // normalize dependency path
      let [, origSpecifierPath] = splitPath(config.from, expandHomeDir(req.specifier));
      let specifierPath = addRelativeCurrentDir(origSpecifierPath);

      if (!(specifierPath in depMap)) {
        specifierPath = origSpecifierPath;
      }

      let depName = depMap[specifierPath]; // handle any file extension renaming, per config

      specifierPath = renameFileExtension(config, specifierPath); // unknown/unnamed dependency?

      if (!depName) {
        specifierPath = req.specifier;
        depName = generateName();
        depMap[specifierPath] = depName;
      } // track which dependencies from the map we've actually referenced


      refDeps[specifierPath] = depName; // process require() statements/expressions

      if (req.esmType == "bare-import") {
        // replace with bare-import statement
        req.context.statement.replaceWith(T.ImportDeclaration([], T.StringLiteral(specifierPath)));
      } else if (req.esmType == "default-import") {
        // replace with default-import statement
        req.context.statement.insertBefore(T.ImportDeclaration([// import * as x from .. ?
        config.namespaceImport ? T.ImportNamespaceSpecifier(T.Identifier(req.binding.target)) : // otherwise, import x from ..
        T.ImportDefaultSpecifier(T.Identifier(req.binding.target))], T.StringLiteral(specifierPath)));
        req.context.declarator.remove();
      } else if (req.esmType == "named-import") {
        // collect named bindings
        let importBindings = [];

        for (let binding of Array.isArray(req.binding) ? req.binding : [req.binding]) {
          let target = T.Identifier(binding.target);
          importBindings.push(binding.source == "default" ? T.ImportDefaultSpecifier(target) : T.ImportSpecifier(target, T.Identifier(binding.source)));
        } // replace with named-import statement


        req.context.statement.insertBefore(T.ImportDeclaration(importBindings, T.StringLiteral(specifierPath)));
        req.context.declarator.remove();
      } else if (req.esmType == "default-import-indirect") {
        // replace with...
        req.context.statement.replaceWithMultiple([// ...default-import statement
        T.ImportDeclaration([config.namespaceImport ? T.ImportNamespaceSpecifier(T.Identifier(req.binding.uniqueTarget)) : T.ImportDefaultSpecifier(T.Identifier(req.binding.uniqueTarget))], T.StringLiteral(specifierPath)), // ...and indirect target assignment
        T.ExpressionStatement(T.AssignmentExpression("=", T.Identifier(req.binding.target), T.Identifier(req.binding.uniqueTarget)))]);
      } else if (req.esmType == "named-import-indirect") {
        // collect named bindings and indirect target assignments
        let importBindings = [];
        let assignments = [];

        for (let binding of Array.isArray(req.binding) ? req.binding : [req.binding]) {
          let uniqTarget = T.Identifier(binding.uniqueTarget);
          importBindings.push(binding.source == "default" ? T.ImportDefaultSpecifier(uniqTarget) : T.ImportSpecifier(uniqTarget, T.Identifier(binding.source)));
          assignments.push(T.ExpressionStatement(T.AssignmentExpression("=", T.Identifier(binding.target), uniqTarget)));
        } // replace with named-import statement and assignments


        req.context.statement.replaceWithMultiple([T.ImportDeclaration(importBindings, T.StringLiteral(specifierPath)), ...assignments]);
      } else if (req.esmType == "substitute-default-import-indirect") {
        let uniqTarget = T.Identifier(req.binding.uniqueTarget); // insert default-import statement

        req.context.statement.insertBefore(T.ImportDeclaration([config.namespaceImport ? T.ImportNamespaceSpecifier(uniqTarget) : T.ImportDefaultSpecifier(uniqTarget)], T.StringLiteral(specifierPath))); // replace require(..) call

        req.context.requireCall.replaceWith(uniqTarget);
      } else if (req.esmType == "substitute-named-import-indirect") {
        let uniqTarget = T.Identifier(req.binding.uniqueTarget); // insert named-import statement

        req.context.statement.insertBefore(T.ImportDeclaration([req.binding.source == "default" ? T.ImportDefaultSpecifier(uniqTarget) : T.ImportSpecifier(uniqTarget, T.Identifier(req.binding.source))], T.StringLiteral(specifierPath))); // replace require(..).x call

        req.context.expression.replaceWith(uniqTarget);
      }
    } // convert all exports


    for (let expt of convertExports) {
      if (expt.esmType == "default-export") {
        // only one default export allowed per module
        registerDefaultExport(expt.context.exportsExpression);
        expt.context.statement.replaceWith(T.ExportDefaultDeclaration(expt.binding.source));
      } else if (expt.esmType == "destructured-declaration-export") {
        expt.context.statement.replaceWith(T.ExportNamedDeclaration(T.VariableDeclaration("let", [T.VariableDeclarator(T.ObjectPattern([T.ObjectProperty(T.Identifier(expt.binding.sourceName), T.Identifier(expt.binding.target),
        /*computed=*/
        false,
        /*shorthand=*/
        expt.binding.sourceName == expt.binding.target)]), expt.binding.source)])));
      } else if (expt.esmType == "named-declaration-export") {
        // default export?
        if (expt.binding.target == "default") {
          // only one default export allowed per module
          registerDefaultExport(expt.context.exportsExpression);
        }

        expt.context.statement.replaceWithMultiple([T.VariableDeclaration("let", [T.VariableDeclarator(T.Identifier(expt.binding.uniqueTarget), expt.binding.source)]), expt.binding.target == "default" ? T.ExportDefaultDeclaration(T.Identifier(expt.binding.uniqueTarget)) : T.ExportNamedDeclaration(null, [T.ExportSpecifier(T.Identifier(expt.binding.uniqueTarget), T.Identifier(expt.binding.target))])]);
      } else if (expt.esmType == "named-export") {
        // default export?
        if (expt.binding.target == "default") {
          // only one default export allowed per module
          registerDefaultExport(expt.context.exportsExpression);
        }

        expt.context.statement.replaceWith(expt.binding.target == "default" ? T.ExportDefaultDeclaration(expt.binding.source) : T.ExportNamedDeclaration(null, [T.ExportSpecifier(T.Identifier(expt.binding.source), T.Identifier(expt.binding.target))]));
      } else if (expt.esmType == "substitute-module-exports-reference") {
        // only one default export allowed per module
        registerDefaultExport(expt.context.exportsExpression);

        if (!$module$exports) {
          $module$exports = createModuleExports(programPath, expt.context.statement, convertExports[convertExports.length - 1].context.statement);
        }

        expt.context.exportsExpression.replaceWith($module$exports);
      }
    } // remove any strict-mode directive (since ESM is automatically strict-mode)


    programAST.program.directives.length = 0;
    return { ...generate(programAST),
      ast: programAST,
      refDeps: depMap,
      pathStr: modulePathStr,
      name: moduleName
    }; // *****************************

    function registerDefaultExport(context) {
      // TODO: include `context` in error reporting
      // already set a default-export? only one allowed per module
      if (defaultExportSet) {
        throw new Error("Multiple default exports not allowed in the same module");
      }

      defaultExportSet = true;
    }
  }

  function index(config, esmBuilds, depMap) {
    var modulePathStr = "./index.js";
    var altModulePathStr = modulePathStr.replace(/\.js$/, ".cjs");
    var moduleName = depMap[modulePathStr || altModulePathStr] || "Index"; // remove a dependency self-reference (if any)

    depMap = Object.fromEntries(Object.entries(depMap).filter(([dPath, dName]) => dPath != modulePathStr && dPath != altModulePathStr)); // handle any file extension renaming, per config

    modulePathStr = renameFileExtension(config, modulePathStr); // start with empty program

    var esmAST = T.File(template.program("")());
    var dependencies = Object.entries(depMap);

    for (let [depPath, depName] of dependencies) {
      // handle any file extension renaming, per config
      depPath = renameFileExtension(config, depPath);
      let target = T.Identifier(depName);
      esmAST.program.body.push(T.ExportNamedDeclaration(null, [// export x from .. ?
      config.exportDefaultFrom ? T.ExportDefaultSpecifier(target) : // export * as x from .. ?
      config.namespaceExport ? T.ExportNamespaceSpecifier(target) : // otherwise, export { default as x } from ..
      T.ExportSpecifier(T.Identifier("default"), target)], T.StringLiteral(depPath)));
    }

    return { ...generate(esmAST),
      ast: esmAST,
      refDeps: depMap,
      pathStr: modulePathStr,
      name: moduleName
    };
  }

  function renameFileExtension(config, pathStr) {
    // handle any file extension renaming, per config
    if (config[".cjs"]) {
      return pathStr.replace(/\.cjs$/, ".js");
    } else if (config[".mjs"]) {
      return pathStr.replace(/\.c?js$/, ".mjs");
    }

    return pathStr;
  }

  function createModuleExports(programPath, firstExportNode, lastExportNode) {
    // setup substitute module-exports target
    var moduleExports = T.Identifier(programPath.scope.generateUidIdentifier("exp").name);
    firstExportNode.insertBefore(T.VariableDeclaration("let", [T.VariableDeclarator(moduleExports, T.ObjectExpression([]))]));
    lastExportNode.insertAfter(T.ExportDefaultDeclaration(moduleExports));
    return moduleExports;
  }

  return _exp;
}], ["Mz", {
  "./umd.js": "UMD",
  "./esm.js": "ESM"
}, function DEF(UMD, ESM) {
  "use strict";

  var buildUMD = UMD;
  var {
    bundle: bundleUMD,
    index: umdIndex
  } = UMD;
  var buildESM = ESM;
  var {
    index: esmIndex
  } = ESM;
  let _exp = {};
  _exp = build;
  _exp.build = build;
  _exp.defaultLibConfig = defaultLibConfig;
  _exp.bundleUMD = bundleUMD;
  _exp.umdIndex = umdIndex;
  _exp.esmIndex = esmIndex;

  function build(config, pathStr, code, depMap = {}) {
    config = defaultLibConfig(config);
    var output = {};

    if (config.buildESM) {
      output.esm = buildESM(config, pathStr, code, depMap);
    }

    if (config.buildUMD) {
      output.umd = buildUMD(config, pathStr, code, depMap);
    }

    return output;
  }

  function defaultLibConfig({
    ignoreUnknownDependency = false,
    ignoreCircularDependency = false,
    ".mjs": renameMJS = false,
    ".cjs": renameCJS = false,
    namespaceImport = false,
    namespaceExport = false,
    exportDefaultFrom = false,
    ...otherConfig
  } = {}) {
    return {
      ignoreUnknownDependency,
      ignoreCircularDependency,
      ".mjs": renameMJS,
      ".cjs": renameCJS,
      namespaceImport,
      namespaceExport,
      exportDefaultFrom,
      ...otherConfig
    };
  }

  return _exp;
}], ["CLI", {
  "path": "Mz_768493518",
  "fs": "Mz_466554158",
  "dotenv": "Mz_324764714",
  "micromatch": "Mz_594362824",
  "minimist": "Mz_52781555",
  "mkdirp": "Mz_387331601",
  "recursive-readdir-sync": "Mz_379234679",
  "./index.js": "Mz",
  "./helpers.js": "Helpers"
}, function DEF(Mz_768493518, Mz_466554158, Mz_324764714, Mz_594362824, Mz_52781555, Mz_387331601, Mz_379234679, Mz, Helpers) {
  "use strict";

  var path = Mz_768493518;
  var fs = Mz_466554158;
  var dotenv = Mz_324764714;
  var micromatch = Mz_594362824;
  var minimist = Mz_52781555;
  var mkdirp = Mz_387331601;
  var recursiveReadDir = Mz_379234679;
  var programVersion;
  var {
    build,
    bundleUMD,
    umdIndex,
    esmIndex,
    defaultLibConfig
  } = Mz;
  var {
    expandHomeDir,
    addRelativeCurrentDir,
    splitPath,
    isDirectory,
    checkPath,
    generateName
  } = Helpers;
  dotenv.config();
  var params = minimist(process.argv.slice(2), {
    boolean: ["help", "version", "build-esm", "build-umd", "recursive"],
    string: ["config", "from", "to", "bundle-umd"],
    alias: {
      "config": "c",
      "recursive": "r",
      "build-esm": "e",
      "build-umd": "u",
      "bundle-umd": "b",
      "dep-map": "m"
    },
    default: {
      help: false,
      version: false,
      recursive: false,
      "build-esm": false,
      "build-umd": false
    }
  });
  var RCPATH = resolvePath(params.config || process.env.RCPATH || "./.mzrc"); // initial CLI-config before reading from rc

  var config = defaultCLIConfig();
  let _exp = {};
  _exp = CLI;
  _exp.CLI = CLI; // ******************************

  function CLI(version = "0.0.0?") {
    programVersion = version;

    if (!loadConfig()) {
      return;
    } // populate known-dependencies map from configuration (if any)


    var knownDeps = {};

    if (config.depMap) {
      for (let [depPath, depName] of Object.entries(config.depMap)) {
        let [, relativePath] = splitPath(config.from, depPath);
        relativePath = addRelativeCurrentDir(relativePath);
        knownDeps[relativePath] = typeof depName == "string" && depName != "" ? depName : generateName();
      }
    } // add discovered input files to known-depenedencies map


    var inputFiles = getInputFiles();

    for (let [, relativePath] of inputFiles) {
      if (!(relativePath in knownDeps)) {
        knownDeps[relativePath] = generateName();
      }
    }

    var umdBuilds = [];
    var esmBuilds = [];

    try {
      // build each file (for each format)
      for (let [basePath, relativePath] of inputFiles) {
        let code = fs.readFileSync(path.join(basePath, relativePath), "utf-8");
        let res = build(config, relativePath, code, knownDeps); // save UMD build (for bundling and/or catch-all generation)?

        if (res.umd && (config.bundleUMDPath || config.generateIndex)) {
          umdBuilds.push(res.umd);
        } // save ESM build (for catch-all generation)?
        else if (res.esm && config.generateIndex) {
            esmBuilds.push(res.esm);
          } // process each output format


        for (let format of ["esm", "umd"]) {
          if (res[format]) {
            let outputPath = path.join(config.to, format, res[format].pathStr);
            let outputDir = path.dirname(outputPath);

            if (!mkdir(outputDir)) {
              throw new Error(`Output directory (${outputDir}) could not be created.`);
            }

            try {
              fs.writeFileSync(outputPath, res[format].code, "utf-8");
            } catch (err) {
              throw new Error(`Output file (${outputPath}) could not be created.`);
            }
          }
        }
      } // generate the catch-all index for each build format


      if (config.generateIndex) {
        if (config.buildUMD) {
          let indexBuild = umdIndex(config, umdBuilds, knownDeps);
          umdBuilds.push(indexBuild);
          let outputPath = path.join(config.to, "umd", indexBuild.pathStr);

          try {
            fs.writeFileSync(outputPath, indexBuild.code, "utf-8");
          } catch (err) {
            throw new Error(`Generated index (${outputPath}) could not be created.`);
          }
        }

        if (config.buildESM) {
          let indexBuild = esmIndex(config, esmBuilds, knownDeps);
          esmBuilds.push(indexBuild);
          let outputPath = path.join(config.to, "esm", indexBuild.pathStr);

          try {
            fs.writeFileSync(outputPath, indexBuild.code, "utf-8");
          } catch (err) {
            throw new Error(`Generated index (${outputPath}) could not be created.`);
          }
        }
      } // need to bundle all the UMDs together?


      if (config.bundleUMDPath && umdBuilds.length > 0) {
        let res = bundleUMD(config, umdBuilds);

        try {
          fs.writeFileSync(config.bundleUMDPath, res.code, "utf-8");
        } catch (err) {
          throw new Error(`UMD bundle (${config.bundleUMDPath}) could not be created.`);
        }
      } // copy any skipped files?


      if (config.copyFiles && config.copyFiles.length > 0) {
        for (let filePathStr of config.copyFiles) {
          let [basePath, relativePath] = splitPath(config.from, filePathStr);
          let fromPathStr = path.join(basePath, relativePath);
          let contents = fs.readFileSync(fromPathStr);

          for (let format of ["esm", "umd"]) {
            if (format == "esm" && config.buildESM || format == "umd" && config.buildUMD) {
              let toPathStr = path.resolve(path.join(config.to, format), relativePath);
              let toDir = path.dirname(toPathStr);

              if (!mkdir(toDir)) {
                throw new Error(`While copying skipped file (${toPathStr}), directory (${toDir}) could not be created.`);
              }

              fs.writeFileSync(toPathStr, contents);
            }
          }
        }
      }
    } catch (err) {
      return showError(err);
    }
  }

  function loadConfig() {
    var cfg;

    try {
      cfg = fs.readFileSync(RCPATH, "utf-8");
    } catch (err) {
      // no config found/available
      cfg = "";
    }

    try {
      cfg = JSON.parse(cfg);
    } catch (err) {
      // config was invalid
      if (!params.help) {
        return showError(`Invalid config: ${RCPATH}`,
        /*includeHelp=*/
        true);
      }
    } // merge in default configs for core and lib


    config = defaultLibConfig(defaultCLIConfig(cfg));
    return checkArgsAndConfig();
  }

  function checkArgsAndConfig() {
    // user asking for help output?
    if (params.help) {
      printHelp();
      return;
    }

    if (params.version) {
      printVersion();
      return;
    } // must build at least one format


    if (!(config.buildESM || config.buildUMD)) {
      return showError("Must select at least one output format (ESM or UMD).",
      /*includeHelp=*/
      true);
    } // from path invalid?


    if (!checkPath(config.from)) {
      return showError(`Input directory (${config.from}) is missing or inaccessible.`);
    } // to path invalid?


    if (!checkPath(config.to)) {
      // should we create the default output target directory?
      if (/\.mz-build$/.test(config.to)) {
        // double-check the path was created?
        if (!mkdir(config.to)) {
          return showError(`Default output directory (${config.to}) could not be created.`);
        }
      } else {
        return showError(`Output directory (${config.to}) is missing or inaccessible.`);
      }

      if (config.buildESM) {
        let esmPath = path.join(config.to, "esm");

        if (!checkPath(esmPath)) {
          if (!mkdir(esmPath)) {
            return showError(`Output directory (${esmPath}) could not be created.`);
          }
        }
      }

      if (config.buildUMD) {
        let umdPath = path.join(config.to, "umd");

        if (!checkPath(umdPath)) {
          if (!mkdir(umdPath)) {
            return showError(`Output directory (${umdPath}) could not be created.`);
          }
        }
      }
    } // path specified to UMD dependency map?


    if (typeof config.depMap == "string") {
      // path is invalid?
      if (!checkPath(config.depMap)) {
        return showError(`Dependency map (${config.depMap}) is missing or inaccessible.`);
      } // load UMD dependency map


      let json;

      try {
        json = JSON.parse(fs.readFileSync(config.depMap, "utf-8")); // need to find config in a package.json?

        if (/package\.json$/.test(config.depMap)) {
          json = json["mz-dependencies"]; // "mz-config" key is missing or not an object?

          if (!json || typeof json != "object") {
            throw true;
          }
        }
      } catch (err) {
        return showError(`Invalid/missing dependency map (${config.depMap}).`);
      }

      config.depMap = json;
    } else if (!("depMap" in config)) {
      if (config.buildUMD) {
        return showError("UMD build format requires dependency map.",
        /*includeHelp=*/
        true);
      }
    }

    return true;
  }

  function getInputFiles() {
    var files; // scan the directory for input files?

    if (isDirectory(config.from)) {
      if (config.recursive) {
        try {
          files = recursiveReadDir(config.from);
        } catch (err) {
          return showError(`Failed scanning for input files (${config.from})`);
          return;
        }
      } else {
        files = fs.readdirSync(config.from).filter(function skipDirs(pathStr) {
          return !isDirectory(pathStr);
        });
      }
    } // otherwise, assume only a single input file
    else {
        files = [config.from];
      } // any skip patterns to remove?


    if (Array.isArray(config.skip) && config.skip.length > 0) {
      files = files.filter(function skipFiles(pathStr) {
        var res = micromatch(pathStr, config.skip).length == 0;

        if ( // skipping file?
        !res && // should copy it?
        config.copyOnSkip) {
          config.copyFiles = config.copyFiles || [];
          config.copyFiles.push(pathStr);
        }

        return res;
      });
    } // split all paths into base and relative


    files = files.map(function fixPaths(pathStr) {
      var [basePath, relativePath] = splitPath(config.from, pathStr);
      return [basePath, addRelativeCurrentDir(relativePath)];
    });
    return files;
  }

  function printHelp() {
    console.log("moduloze usage:");
    console.log("  mz {OPTIONS}");
    console.log("");
    console.log("--help                     print this help");
    console.log("--version                  print version info");
    console.log("--config={PATH}, -c        path to load config");
    console.log(`                           [${RCPATH}]`);
    console.log("--from={PATH}              scan directory for input file(s)");
    console.log(`                           [${config.from}]`);
    console.log("--to={PATH}                target directory for output file(s)");
    console.log(`                           [${config.to}]`);
    console.log("--dep-map={PATH}, -m       dependency map file");
    console.log(`                           [${config.depMap}]`);
    console.log("--recursive, -r            scan recursively for input files");
    console.log(`                           [${config.recursive}]`);
    console.log("--build-esm, -e            build ES-Modules format from input file(s)");
    console.log(`                           [${config.buildESM}]`);
    console.log("--build-umd, -u            build UMD format from input file(s)");
    console.log(`                           [${config.buildUMD}]`);
    console.log("--bundle-umd={PATH}, -b    include UMD bundle");
    console.log(`                           [${config.bundleUMDPath || "./umd/bundle.js"}]`);
    console.log("");
  }

  function printVersion() {
    console.log(`v${programVersion}`);
  }

  function showError(err, includeHelp = false) {
    console.error(err.toString());

    if (includeHelp) {
      console.log("");
      printHelp();
    }

    process.exit(1);
  }

  function defaultCLIConfig({
    from = process.env.FROMPATH,
    to = process.env.TOPATH,
    depMap = process.env.DEPMAPPATH,
    bundleUMDPath,
    skip = [],
    copyOnSkip = false,
    copyFiles = [],
    recursive,
    buildESM,
    buildUMD,
    generateIndex = false,
    ...other
  } = {}) {
    // params override configs
    from = resolvePath(params.from || from || "./");
    to = resolvePath(params.to || to || "./.mz-build");
    depMap = typeof depMap == "string" || typeof depMap == "undefined" ? resolvePath(params["dep-map"] || depMap || "./package.json") : depMap;
    bundleUMDPath = "bundle-umd" in params || bundleUMDPath || "UMDBUNDLEPATH" in process.env ? resolvePath(params["bundle-umd"] || bundleUMDPath || process.env.UMDBUNDLEPATH || "./umd/bundle.js", to) : false;
    recursive = params.recursive || recursive;
    buildESM = params["build-esm"] || buildESM;
    buildUMD = params["build-umd"] || buildUMD;
    return {
      from,
      to,
      recursive,
      buildESM,
      buildUMD,
      skip,
      copyOnSkip,
      copyFiles,
      depMap,
      bundleUMDPath,
      generateIndex,
      ...other
    };
  }

  function resolvePath(pathStr, basePath = process.cwd()) {
    pathStr = expandHomeDir(pathStr);
    return path.resolve(basePath, pathStr);
  }

  function mkdir(pathStr) {
    try {
      mkdirp.sync(pathStr);
      return true;
    } catch (err) {
      return err;
    }
  }

  return _exp;
}]]);